@@ -1,4 +1,4 @@
-#' Helper for consistent documentation
+#' Helper for consistent documentation of empty dots
 #'
 #' Use `@inheritParams ellipsis::dots_empty` in your package
 #' to consistently document an unused `...` argument.
@@ -8,6 +8,16 @@
 #' @keywords internal
 NULL
 
+#' Helper for consistent documentation of used dots
+#'
+#' Use `@inheritParams ellipsis::dots_used` in your package
+#' to consistently document an unused `...` argument.
+#'
+#' @param ... Arguments passed to methods.
+#' @name dots_used
+#' @keywords internal
+NULL
+
 #' @useDynLib ellipsis, .registration = TRUE
 dots <- function(env = parent.frame(), auto_name = TRUE) {
   .Call(ellipsis_dots, env, auto_name)
